CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
59 lines
2.0 KiB
C++
59 lines
2.0 KiB
C++
//===----------------------------------------------------------------------===//
|
|
//
|
|
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
|
|
// See https://llvm.org/LICENSE.txt for license information.
|
|
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
|
//
|
|
//===----------------------------------------------------------------------===//
|
|
#ifndef SUPPORT_USER_DEFINED_INTEGRAL_H
|
|
#define SUPPORT_USER_DEFINED_INTEGRAL_H
|
|
|
|
template <class T>
|
|
struct UserDefinedIntegral
|
|
{
|
|
__host__ __device__ constexpr UserDefinedIntegral()
|
|
: value(0)
|
|
{}
|
|
__host__ __device__ constexpr UserDefinedIntegral(T v)
|
|
: value(v)
|
|
{}
|
|
__host__ __device__ constexpr operator T() const
|
|
{
|
|
return value;
|
|
}
|
|
T value;
|
|
};
|
|
|
|
// Poison the arithmetic and comparison operations
|
|
template <class T, class U>
|
|
__host__ __device__ constexpr void operator+(UserDefinedIntegral<T>, UserDefinedIntegral<U>);
|
|
|
|
template <class T, class U>
|
|
__host__ __device__ constexpr void operator-(UserDefinedIntegral<T>, UserDefinedIntegral<U>);
|
|
|
|
template <class T, class U>
|
|
__host__ __device__ constexpr void operator*(UserDefinedIntegral<T>, UserDefinedIntegral<U>);
|
|
|
|
template <class T, class U>
|
|
__host__ __device__ constexpr void operator/(UserDefinedIntegral<T>, UserDefinedIntegral<U>);
|
|
|
|
template <class T, class U>
|
|
__host__ __device__ constexpr void operator==(UserDefinedIntegral<T>, UserDefinedIntegral<U>);
|
|
|
|
template <class T, class U>
|
|
__host__ __device__ constexpr void operator!=(UserDefinedIntegral<T>, UserDefinedIntegral<U>);
|
|
|
|
template <class T, class U>
|
|
__host__ __device__ constexpr void operator<(UserDefinedIntegral<T>, UserDefinedIntegral<U>);
|
|
|
|
template <class T, class U>
|
|
__host__ __device__ constexpr void operator>(UserDefinedIntegral<T>, UserDefinedIntegral<U>);
|
|
|
|
template <class T, class U>
|
|
__host__ __device__ constexpr void operator<=(UserDefinedIntegral<T>, UserDefinedIntegral<U>);
|
|
|
|
template <class T, class U>
|
|
__host__ __device__ constexpr void operator>=(UserDefinedIntegral<T>, UserDefinedIntegral<U>);
|
|
|
|
#endif // SUPPORT_USER_DEFINED_INTEGRAL_H
|